<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * This file is part of the PEAR Testing_DocTest package.
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to the MIT license that is available
 * through the world-wide-web at the following URI:
 * http://opensource.org/licenses/mit-license.php
 *
 * @category  Testing 
 * @package   Testing_DocTest
 * @author    David JEAN LOUIS <izimobil@gmail.com>
 * @copyright 2008 David JEAN LOUIS
 * @license   http://opensource.org/licenses/mit-license.php MIT License 
 * @version   CVS: $Id$
 * @link      http://pear.php.net/package/Testing_DocTest
 * @since     File available since release 0.1.0
 * @filesource
 */

/**
 * DocTest Outputter interface.
 * All outputters must implement this interface.
 *
 * @category  Testing
 * @package   Testing_DocTest
 * @author    David JEAN LOUIS <izimobil@gmail.com>
 * @copyright 2008 David JEAN LOUIS
 * @license   http://opensource.org/licenses/mit-license.php MIT License 
 * @version   Release: 0.3.0
 * @link      http://pear.php.net/package/Testing_DocTest
 * @since     Class available since release 0.1.0
 */
interface Testing_DocTest_OutputterInterface
{
    // begin() {{{

    /**
     * Begin of the DocTest session.
     * The array parameter is as follows:
     *
     * <code>
     * array(
     *     '/path/to/file1.php' => array($testCase1, $testCase2),
     *     '/path/to/file2.php' => array($testCase3, $testCase4),
     *     [...]
     *     '/path/to/fileN.php' => array($testCaseN),
     * )
     * </code>
     *
     * Note that the test cases provided in the array have not been run yet.
     *
     * @param array $files a multidimensional array of file=>testcase array 
     *
     * @access public
     * @return void
     */
    public function begin(array $files);

    // }}}
    // end() {{{

    /**
     * End of the DocTest session.
     * The array parameter is as follows:
     *
     * <code>
     * array(
     *     '/path/to/file1.php' => array($testCase1, $testCase2),
     *     '/path/to/file2.php' => array($testCase3, $testCase4),
     *     [...]
     *     '/path/to/fileN.php' => array($testCaseN),
     * )
     * </code>
     *
     * @param array $files a multidimensional array of file=>testcase array 
     *
     * @access public
     * @return void
     */
    public function end(array $files);

    // }}}
    // beginFile() {{{

    /**
     * Begin of file parsing.
     *
     * Note that the test cases provided in the array have not been run yet.
     *
     * @param string $file          path to the file that will be processed
     * @param array  $testCaseArray an array of test case instances
     *
     * @access public
     * @return void
     */
    public function beginFile($file, array $testCaseArray);

    // }}}
    // endFile() {{{

    /**
     * End of file parsing.
     *
     * @param string $file          path to the file that will be processed
     * @param array  $testCaseArray an array of test case instances
     *
     * @access public
     * @return void
     */
    public function endFile($file, array $testCaseArray);

    // }}}
    // beginTestCase() {{{

    /**
     * Begin of test case parsing.
     *
     * Note that the test case provided have not been run yet.
     *
     * @param object $testCase a test case instance
     *
     * @access public
     * @return void
     */
    public function beginTestCase(Testing_DocTest_TestCase $testCase);

    // }}}
    // endTestCase() {{{

    /**
     * End of test case parsing.
     *
     * @param object $testCase a test case instance
     *
     * @access public
     * @return void
     */
    public function endTestCase(Testing_DocTest_TestCase $testCase);

    // }}}
}
